#!/usr/bin/python
#
# Copyright (c) 2020 Blickfeld GmbH.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE.md file in the root directory of this source tree.
#

from __future__ import print_function

try:
    from zeroconf import ServiceBrowser, Zeroconf, InterfaceChoice
except:
    Zeroconf = None

import time

__all__ = [
    "search_and_connect",
    "search_one_and_connect"
]

from .scanner import scanner

def __discover(duration):
    infos = []

    class ServiceListener:
        def remove_service(self, zeroconf, type, name):
            pass

        def add_service(self, zeroconf, type, name):
            info = zeroconf.get_service_info(type, name)
            infos.append(info)
            zeroconf.notify_all()
            
    if Zeroconf is None:
        raise Exception("Either not supported with this python version or package `zeroconf` is broken.")

    zeroconf = Zeroconf(interfaces=InterfaceChoice.All)
    ServiceBrowser(zeroconf, "_blickfeld-lidar._tcp.local.", ServiceListener())
    
    while duration > 0:
        start = time.time()
        zeroconf.wait(duration)
        duration = duration - (time.time() - start)
        
    zeroconf.close()
    
    return infos

def search_and_connect(duration = 3):
    """ Find Blickfeld devices in the network and connect to them.

    :param duration: duration of network search in seconds
    :return: list of BSL scanner objects, [:py:class:`blickfeld_scanner.scanner`]
    """
    scanners = []
    for info in __discover(duration):
        try:
            scanners.append(scanner(info.parsed_addresses()[0], name=info.server))
        except:
            pass
    return scanners
        
def search_one_and_connect(duration = 3):
    """ Find Blickfeld device in the network and connect to it, 
    if multiple devices are available, the first device discovered will be selected.

    :param duration: duration of network search in seconds
    :return: :py:class:`blickfeld_scanner.scanner` object or None if no device is found, 
    """
    infos = __discover(duration)
    if not len(infos):
        return None
    return scanner(infos[0].parsed_addresses()[0], name=infos[0].server)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/update/hardware.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/update/hardware.proto',
  package='blickfeld.protocol.update',
  syntax='proto2',
  serialized_options=_b('H\002'),
  serialized_pb=_b('\n\x1f\x62lickfeld/update/hardware.proto\x12\x19\x62lickfeld.protocol.update\x1a\x17\x62lickfeld/options.proto\"`\n\x18partial_trenz_eeprom_msg\x12\x44\n\x10hardware_variant\x18\x03 \x01(\x0e\x32*.blickfeld.protocol.update.HardwareVariant\"5\n\x19partial_module_eeprom_msg\x12\x18\n\x10hardware_version\x18\x63 \x01(\t*\x96\x01\n\x0fHardwareVariant\x12\x10\n\x0c\x41LL_HARDWARE\x10\x05\x12\x14\n\x10UNKNOWN_HARDWARE\x10\x06\x12\x0f\n\x0bNO_HARDWARE\x10\x07\x12\r\n\tCUBE_V0_2\x10\x00\x12\r\n\tCUBE_V0_3\x10\x01\x12\r\n\tCUBE_V1_0\x10\x04\x12\r\n\tAURORA_P3\x10\x03\x12\x0e\n\nAPOLLON_A0\x10\x02\x42\x02H\x02')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])

_HARDWAREVARIANT = _descriptor.EnumDescriptor(
  name='HardwareVariant',
  full_name='blickfeld.protocol.update.HardwareVariant',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL_HARDWARE', index=0, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_HARDWARE', index=1, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_HARDWARE', index=2, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUBE_V0_2', index=3, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUBE_V0_3', index=4, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUBE_V1_0', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AURORA_P3', index=6, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APOLLON_A0', index=7, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=241,
  serialized_end=391,
)
_sym_db.RegisterEnumDescriptor(_HARDWAREVARIANT)

HardwareVariant = enum_type_wrapper.EnumTypeWrapper(_HARDWAREVARIANT)
ALL_HARDWARE = 5
UNKNOWN_HARDWARE = 6
NO_HARDWARE = 7
CUBE_V0_2 = 0
CUBE_V0_3 = 1
CUBE_V1_0 = 4
AURORA_P3 = 3
APOLLON_A0 = 2



_PARTIAL_TRENZ_EEPROM_MSG = _descriptor.Descriptor(
  name='partial_trenz_eeprom_msg',
  full_name='blickfeld.protocol.update.partial_trenz_eeprom_msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware_variant', full_name='blickfeld.protocol.update.partial_trenz_eeprom_msg.hardware_variant', index=0,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=183,
)


_PARTIAL_MODULE_EEPROM_MSG = _descriptor.Descriptor(
  name='partial_module_eeprom_msg',
  full_name='blickfeld.protocol.update.partial_module_eeprom_msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware_version', full_name='blickfeld.protocol.update.partial_module_eeprom_msg.hardware_version', index=0,
      number=99, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=238,
)

_PARTIAL_TRENZ_EEPROM_MSG.fields_by_name['hardware_variant'].enum_type = _HARDWAREVARIANT
DESCRIPTOR.message_types_by_name['partial_trenz_eeprom_msg'] = _PARTIAL_TRENZ_EEPROM_MSG
DESCRIPTOR.message_types_by_name['partial_module_eeprom_msg'] = _PARTIAL_MODULE_EEPROM_MSG
DESCRIPTOR.enum_types_by_name['HardwareVariant'] = _HARDWAREVARIANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

partial_trenz_eeprom_msg = _reflection.GeneratedProtocolMessageType('partial_trenz_eeprom_msg', (_message.Message,), dict(
  DESCRIPTOR = _PARTIAL_TRENZ_EEPROM_MSG,
  __module__ = 'blickfeld.update.hardware_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.update.partial_trenz_eeprom_msg)
  ))
_sym_db.RegisterMessage(partial_trenz_eeprom_msg)

partial_module_eeprom_msg = _reflection.GeneratedProtocolMessageType('partial_module_eeprom_msg', (_message.Message,), dict(
  DESCRIPTOR = _PARTIAL_MODULE_EEPROM_MSG,
  __module__ = 'blickfeld.update.hardware_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.update.partial_module_eeprom_msg)
  ))
_sym_db.RegisterMessage(partial_module_eeprom_msg)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/python
#
# Copyright (c) 2020 Blickfeld GmbH.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE.md file in the root directory of this source tree.
#

from __future__ import print_function

import logging
import re
import socket
import struct
import ssl
import tempfile
import os

from .protocol import connection_pb2
from .protocol import options_pb2
from . import stream

log = logging.getLogger(__name__)

class scanner(object):
    """
    Scanner is a class to connect to a device, get a point cloud stream, get a status stream and set a scan pattern.

    :param hostname_or_ip: Device to which the connection should be established.
    :type hostname_or_ip: str
    :param port: Port on which the device is reachable the default is 8000.
    :type port: int
    :param name: Name of the device used for string representation.
    :type name: str
    :param key_and_cert_file: Filename containing a private key and certificate for SSL connection.
    :type key_and_cert_file: str
    :param key_and_cert: String containing a private key and certificate for SSL connection.
    :type key_and_cert: str
    """
    protocol_version = 1
    _default_port = 8000
    _default_ssl_port = 8800
    
    def __init__(self, hostname_or_ip="localhost", port=None, name=None, key_and_cert_file=None, key_and_cert=None):
        self.hostname_or_ip = hostname_or_ip
        self.name = name if name is not None else self.hostname_or_ip
        self.api_path = "http://" + hostname_or_ip + "/api/v1/"
        
        self._key_and_cert = None
        if key_and_cert_file:
            with open(key_and_cert_file,'r') as f:
                self._key_and_cert = f.read()
        elif key_and_cert:
            self._key_and_cert = key_and_cert
        self.has_ssl = self._key_and_cert != None

        if port != None:
            self.port = port
        else:
            self.port = self._default_ssl_port if self.has_ssl else self._default_port
        
        self._connection = self.create_connection()
        
        req = connection_pb2.Request()
        req.hello.protocol_version = self.protocol_version
        self._connection.send_request(req)

    def __del__(self):
        if hasattr(self, "_connection"):
            self._connection.close()
            
    def __repr__(self):
        return "<Blickfeld Scanner '%s'>" % ( self.name )

    def get_status(self):
        """ Request status of device

        :returns: Status object, see :any:`protobuf_protocol` Status
        """
        req = connection_pb2.Request()
        req.status.SetInParent()
        return self._connection.send_request(req).status

    def get_status_stream(self):
        """ Request status stream of device

        This returns a status stream, which only delivers updates when the device has changed.
        Do not use this in a synchronous blocking call. Use the `get_status` method instead.

        :returns: :py:class:`blickfeld_scanner.scanner.status_stream` object
        """
        return status_stream(self.create_connection())

    def get_point_cloud_stream(self):
        """ Request point cloud stream of device

        :returns: :py:class:`blickfeld_scanner.scanner.point_cloud_stream` object
        """
        return stream.point_cloud(self.create_connection())

    @staticmethod
    def file_point_cloud_stream(dump_filename):
        """ Request a point_cloud_stream, which streams off a .bfpc file.
        No device (and connection to a device) is needed for this operation.

        :param dump_filename: path to .bfpc file
        :return: :py:class:`blickfeld_scanner.scanner.point_cloud_stream` object
        """
        return stream.point_cloud(from_file=dump_filename)
    
    def set_scan_pattern(self, config, persist = False):
        """ Function to set a new scan pattern, see: :any:`protobuf_protocol`.
        First call :py:func:`blickfeld_scanner.scanner.scanner.fill_scan_pattern` with the scan pattern you want to set and
        then use that returned scan pattern as a config in this function.

        :param config: scan pattern to be set
        :param persist: Persist scan pattern on device and reload it after a power-cycle, see: :any:`protobuf_protocol` scan pattern
        :return: response scan pattern, see :any:`protobuf_protocol` Connection, see :any:`protobuf_protocol` Connection
        """
        req = connection_pb2.Request()
        req.set_scan_pattern.config.MergeFrom(config)
        req.set_scan_pattern.persist = persist
        return self._connection.send_request(req).set_scan_pattern
    
    def fill_scan_pattern(self, config):
        """ Function to fill a scan pattern, see: :any:`protobuf_protocol`. The device fill the missing fields with default values and return it. After it is filled the scan pattern can be set with the :py:func:`blickfeld_scanner.scanner.scanner.set_scan_pattern` function.

        :param config: scan pattern to be filled by the BSS, see: :any:`protobuf_protocol` scan pattern
        :return: Filled scan pattern, which can be set, see :any:`protobuf_protocol` scan pattern
        """
        req = connection_pb2.Request()
        req.fill_scan_pattern.config.MergeFrom(config)
        return self._connection.send_request(req).fill_scan_pattern.config
    
    def get_scan_pattern(self):
        """ Returns the currently set scan pattern, see: :any:`protobuf_protocol`.

        :return: Currently set scan pattern, see :any:`protobuf_protocol` scan pattern
        """
        req = connection_pb2.Request()
        req.get_scan_pattern.SetInParent()
        return self._connection.send_request(req).get_scan_pattern.config
    
    def get_device_timestamp(self):
        """Returns the current device timestamp in seconds.

        :return: Current device timestamp in seconds
        """
        req = connection_pb2.Request()
        req.hello.protocol_version = self.protocol_version
        return self._connection.send_request(req).timestamp_ns / 1e9
    
    def get_ntp_server(self):
        """Attention: To use this function you need the requests library
        `https://requests.readthedocs.io/en/master/`

        Function to get a ntp server

        :return: Returns the ntp server IP address
        """
        import requests
        req = requests.get(self.api_path + "network/ntp")
        req.raise_for_status()
        return req.json()['data']['server']
    
    def set_ntp_server(self, server):
        """Attention: To use this function you need the requests library
        `https://requests.readthedocs.io/en/master/`

        Function to set a ntp server

        :param server: Server IP to set the ntp server to
        :type server: str
        """
        import requests
        import json
        cur_server = self.get_ntp_server()
        if cur_server != server:
            req = requests.put(self.api_path + "network/ntp/server", data=json.dumps({ "data": server }), headers={"Content-Type": "application/json"})
            req.raise_for_status()
            log.info("Configured NTP server to '%s'. Please power cycle the device to apply changes." % (self.get_ntp_server()))
        
    def create_connection(self):
        """Function to create a new connection
        
        :return: Newly created :py:class:`blickfeld_scanner.scanner.connection`
        """
        return connection(self.hostname_or_ip, self.port, self._key_and_cert)
 
    @staticmethod
    def sync(devices, scan_pattern = None, target_frame_rate = None, max_time_difference = 0.1):
        """ Sync two or more devices to record frames at the same time.

        :param server: list of scanners to sync
        :type server: list of :py:class:`blickfeld_scanner.scanner.scanner`
        :param scan_pattern: scan pattern that the devices should use, if None is given, it will select the current scan pattern
        :type scan_pattern: scan pattern, see: :any:`protobuf_protocol`,
        :param target_frame_rate: Frame rate that the devices should run. Maximum frame rate is dependent on the scan pattern, if None is given the maximum possible frame rate will be used.
        :type target_frame_rate: float
        :param max_time_difference: Maximum time difference allowed.
        :type max_time_difference: float
        """
        max_frame_rate = None
        for device in devices:
            sp_device = device.fill_scan_pattern(scan_pattern) if scan_pattern is not None else device.get_scan_pattern()
            if max_frame_rate is None or sp_device.frame_rate.maximum < max_frame_rate:
                max_frame_rate = sp_device.frame_rate.maximum
        
        if target_frame_rate and target_frame_rate < max_frame_rate:
            frame_rate = target_frame_rate
        else:
            frame_rate = max_frame_rate
        
        log.info("Syncing to frame rate %0.2f Hz (maximum %0.2f Hz)" % (frame_rate, max_frame_rate))
        
        for device in devices:
            sp_device = device.fill_scan_pattern(scan_pattern) if scan_pattern is not None else device.get_scan_pattern()
            sp_device.frame_rate.target = frame_rate
            device.set_scan_pattern(sp_device)
        log.info("Sync triggered")
        
        timestamps = []
        total_diff = 0
        for device in devices:
            timestamps.append(device.get_device_timestamp())
        for i, ts in enumerate(timestamps[1:], 1):
            diff = abs(timestamps[0] - ts)
            total_diff = total_diff + diff
            if diff > max_time_difference:
                raise Exception("Device timestamps are not synced (%s: %fs, %s: %fs => diff %fs)." 
                    % (devices[i].hostname_or_ip, ts, devices[0].hostname_or_ip, timestamps[0], diff))
        log.info("Total time difference with serial requests %0.3fs" % (total_diff))

class protocol_exception(Exception):
    """ Protocol exception class for errors, see errors in :any:`protobuf_protocol`

    :param value: Exception that occured
    :type value: Protocol Exception, see: :any:`protobuf_protocol`
    """
    def __init__(self, value):
        self.error = value

    def __format(self):
        e_desc = self.description()
        for match in re.finditer(re.compile(r"(\{([a-z_]+)\:(\%\d*\.*\d*[fsdu])\})"), e_desc):
            template, key, fmt = match.groups()
            if self.__contained_error().HasField(key):
                e_desc = e_desc.replace(template, str(fmt % getattr(self.__contained_error(), key)))
        return self.name() + str(": (errno: {})").format(self.errno()) + "\n\t" + e_desc
        
    def __field(self):
        return self.error.DESCRIPTOR.fields_by_name[str(self.error.WhichOneof("error"))]

    def __contained_error(self):
        return getattr(self.error, self.error.WhichOneof("error"))
        
    def errno(self):
        """ Returns error number

        :return: Error number
        """
        return self.__field().number
    
    def name(self):
        """ Returns error name as in :any:`protobuf_protocol`

        :return: Error name
        """
        return self.__field().message_type.full_name
    
    def description(self):
        """ Returns error description as in :any:`protobuf_protocol`

        :return: Error description
        """
        return self.__field().message_type.GetOptions().Extensions[options_pb2.e_desc]
        
    def __str__(self):
        return self.__format()
   
class connection(object):
    """ Class to create a connection to the Blickfeld LiDAR device

    :param hostname_or_ip: hostname or IP to which the connection should be established
    :type hostname_or_ip: str
    :param port: port on which the connection should be established
    :type port: int
    :param key_and_cert: String containing a private key and certificate for SSL connection
    :type key_and_cert: str
    :param ssl_protocol: The protocol used for an SSL connection
    :type ssl_protocol: see ssl lib: `ssl.PROTOCOL_...`
    """
    def __init__(self, hostname_or_ip, port, key_and_cert=None, ssl_protocol=ssl.PROTOCOL_TLS):
        self._key_and_cert = key_and_cert
        self.has_ssl = self._key_and_cert != None
        if self.has_ssl:
            self._ssl_context = ssl.SSLContext(ssl_protocol)
            
            # Write cert in temporary file
            fd, key_and_cert_file = tempfile.mkstemp()
            with open(fd, 'w') as f:
                f.write(self._key_and_cert)
            try:
                self._ssl_context.load_cert_chain(key_and_cert_file)
                self._ssl_context.load_verify_locations(key_and_cert_file)
            except:
                os.unlink(key_and_cert_file)
                raise
            os.unlink(key_and_cert_file)
            
            self._ssl_context.verify_mode = ssl.CERT_REQUIRED
            self.socket = self._ssl_context.wrap_socket(socket.create_connection((hostname_or_ip, port)), server_hostname=hostname_or_ip)
        else:
            self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            self.socket.connect((hostname_or_ip, port))
         
    def __del__(self):
        self.close()

    def clone(self, other_hostname_or_ip=None, other_port=None, other_key_and_cert=None):
        """ Copies connection object.
        
        :param other_hostname_or_ip: a different hostname or IP to use for the clone
        :type other_hostname_or_ip: str
        :param other port: a different port to use for the clone
        :type other port: int
        :param other_key_and_cert: a different string containing a private key and certificate for the clone
        :type other_key_and_cert: str
        """
        (old_hostname_or_ip, old_port) = self.socket.getpeername()

        return connection(other_hostname_or_ip or old_hostname_or_ip, 
                          other_port or old_port,
                          other_key_and_cert or self._key_and_cert)
        
    def send_request(self, req):
        """ Send request to the device

        :param req: Request to the device
        :type req: Request, see: :any:`protobuf_protocol`
        :return: Response of the device, see: :any:`protobuf_protocol`
        """
        self.send(req)
        return self.recv()

    def send(self, req):
        """ Send request to the device

        :param req: Request to the device
        :type req: Request, see: :any:`protobuf_protocol`
        """
        data = req.SerializeToString()

        self.socket.send(struct.pack('<I', len(data)))
        self.socket.send(data)

    def recv(self):
        """ Receive response of the device

        :return: Response of the device, see: :any:`protobuf_protocol`
        """
        len = struct.unpack('<I', self.__recv_all(4))[0]
        recv = connection_pb2.Response()
        recv.ParseFromString(self.__recv_all(len))

        if recv.HasField('error'):
            raise protocol_exception(recv.error)

        return recv

    def __recv_all(self, n):
        data = b''
        while len(data) < n:
            packet = self.socket.recv(n - len(data))
            if not packet:
                return None
            data += packet
        return data

    def close(self):
        """ Close connection to the device
        """
        if hasattr(self, "socket"):
            self.socket.close()



class status_stream(object):
    """Class to request a status stream

    :param connection: connection to the device
    :type connection: :py:class:`blickfeld_scanner.scanner.connection`
    """
    def __init__(self, connection):
        self._connection = connection

        req = connection_pb2.Request()
        req.subscribe.status.SetInParent()
        ret = self._connection.send_request(req)

    def __del__(self):
        self.close()

    def close(self):
        """ Close stream and connection
        """
        self._connection.close()

    def recv_status(self):
        """ Receive status update

        :return: Status messages of the device, see: :any:`protobuf_protocol`
        """
        return self._connection.recv().event.status



#!/usr/bin/python
#
# Copyright (c) 2020 Blickfeld GmbH.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE.md file in the root directory of this source tree.
#

from __future__ import print_function

__all__ = [
    "__version__",
    "scanner",
    "discover"
]

from .version import __version__
from . import scanner as bf_scanner
from . import discover

scanner = bf_scanner.scanner




import os
import setuptools
from io import open

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name="blickfeld_scanner",
    version="2.9.1",
    author="Blickfeld GmbH",
    author_email="opensource@blickfeld.com",
    description="Python package to communicate with LiDAR devices of the Blickfeld GmbH.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/Blickfeld/blickfeld-scanner-lib",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
        "Topic :: Utilities",
    ],
    install_requires=[
    	'protobuf>=3.6.1',
    	'zeroconf'
	],
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/main.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..status import scanner_pb2 as blickfeld_dot_status_dot_scanner__pb2
from ..status import temperature_pb2 as blickfeld_dot_status_dot_temperature__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/main.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1b\x62lickfeld/status/main.proto\x12\x12\x62lickfeld.protocol\x1a\x1e\x62lickfeld/status/scanner.proto\x1a\"blickfeld/status/temperature.proto\"{\n\x06Status\x12\x33\n\x07scanner\x18\x01 \x01(\x0b\x32\".blickfeld.protocol.status.Scanner\x12<\n\x0ctemperatures\x18\x02 \x03(\x0b\x32&.blickfeld.protocol.status.Temperature')
  ,
  dependencies=[blickfeld_dot_status_dot_scanner__pb2.DESCRIPTOR,blickfeld_dot_status_dot_temperature__pb2.DESCRIPTOR,])




_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scanner', full_name='blickfeld.protocol.Status.scanner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperatures', full_name='blickfeld.protocol.Status.temperatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=242,
)

_STATUS.fields_by_name['scanner'].message_type = blickfeld_dot_status_dot_scanner__pb2._SCANNER
_STATUS.fields_by_name['temperatures'].message_type = blickfeld_dot_status_dot_temperature__pb2._TEMPERATURE
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'blickfeld.status.main_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Status)
  ))
_sym_db.RegisterMessage(Status)


# @@protoc_insertion_point(module_scope)
